/* Automatically @generated by tree-sitter v0.25.8 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 153
#define LARGE_STATE_COUNT 4
#define SYMBOL_COUNT 59
#define ALIAS_COUNT 0
#define TOKEN_COUNT 31
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 7
#define MAX_ALIAS_SEQUENCE_LENGTH 7
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 8
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_var = 1,
  anon_sym_COMMA = 2,
  anon_sym_SEMI = 3,
  anon_sym_let = 4,
  anon_sym_const = 5,
  anon_sym_EQ = 6,
  anon_sym_DOLLAR_COLON = 7,
  anon_sym_COLON = 8,
  anon_sym_LPAREN = 9,
  anon_sym_RPAREN = 10,
  anon_sym_DOT = 11,
  anon_sym_PLUS = 12,
  anon_sym_DASH = 13,
  anon_sym_STAR = 14,
  anon_sym_SLASH = 15,
  anon_sym_EQ_GT = 16,
  anon_sym_LBRACE = 17,
  anon_sym_RBRACE = 18,
  anon_sym_LBRACK = 19,
  anon_sym_RBRACK = 20,
  anon_sym_DQUOTE = 21,
  aux_sym_string_token1 = 22,
  aux_sym_string_token2 = 23,
  anon_sym_SQUOTE = 24,
  aux_sym_string_token3 = 25,
  anon_sym_BQUOTE = 26,
  aux_sym_string_token4 = 27,
  sym_number = 28,
  sym_identifier = 29,
  sym_comment = 30,
  sym_source_file = 31,
  sym__statement = 32,
  sym_variable_declaration = 33,
  sym_lexical_declaration = 34,
  sym_variable_declarator = 35,
  sym__initializer = 36,
  sym_assignment = 37,
  sym_function_call = 38,
  sym_method_call = 39,
  sym_chained_method = 40,
  sym_binary_expression = 41,
  sym_additive_expression = 42,
  sym_multiplicative_expression = 43,
  sym_arrow_function = 44,
  sym_expression = 45,
  sym__base_expression = 46,
  sym_object = 47,
  sym_pair = 48,
  sym_array = 49,
  sym_string = 50,
  aux_sym_source_file_repeat1 = 51,
  aux_sym_variable_declaration_repeat1 = 52,
  aux_sym_function_call_repeat1 = 53,
  aux_sym_chained_method_repeat1 = 54,
  aux_sym_object_repeat1 = 55,
  aux_sym_string_repeat1 = 56,
  aux_sym_string_repeat2 = 57,
  aux_sym_string_repeat3 = 58,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_var] = "var",
  [anon_sym_COMMA] = ",",
  [anon_sym_SEMI] = ";",
  [anon_sym_let] = "let",
  [anon_sym_const] = "const",
  [anon_sym_EQ] = "=",
  [anon_sym_DOLLAR_COLON] = "$:",
  [anon_sym_COLON] = ":",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_DOT] = ".",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_token1] = "string_token1",
  [aux_sym_string_token2] = "string_token2",
  [anon_sym_SQUOTE] = "'",
  [aux_sym_string_token3] = "string_token3",
  [anon_sym_BQUOTE] = "`",
  [aux_sym_string_token4] = "string_token4",
  [sym_number] = "number",
  [sym_identifier] = "identifier",
  [sym_comment] = "comment",
  [sym_source_file] = "source_file",
  [sym__statement] = "_statement",
  [sym_variable_declaration] = "variable_declaration",
  [sym_lexical_declaration] = "lexical_declaration",
  [sym_variable_declarator] = "variable_declarator",
  [sym__initializer] = "_initializer",
  [sym_assignment] = "assignment",
  [sym_function_call] = "function_call",
  [sym_method_call] = "method_call",
  [sym_chained_method] = "chained_method",
  [sym_binary_expression] = "binary_expression",
  [sym_additive_expression] = "additive_expression",
  [sym_multiplicative_expression] = "multiplicative_expression",
  [sym_arrow_function] = "arrow_function",
  [sym_expression] = "expression",
  [sym__base_expression] = "_base_expression",
  [sym_object] = "object",
  [sym_pair] = "pair",
  [sym_array] = "array",
  [sym_string] = "string",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_variable_declaration_repeat1] = "variable_declaration_repeat1",
  [aux_sym_function_call_repeat1] = "function_call_repeat1",
  [aux_sym_chained_method_repeat1] = "chained_method_repeat1",
  [aux_sym_object_repeat1] = "object_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_string_repeat2] = "string_repeat2",
  [aux_sym_string_repeat3] = "string_repeat3",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_var] = anon_sym_var,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_let] = anon_sym_let,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_DOLLAR_COLON] = anon_sym_DOLLAR_COLON,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_token1] = aux_sym_string_token1,
  [aux_sym_string_token2] = aux_sym_string_token2,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym_string_token3] = aux_sym_string_token3,
  [anon_sym_BQUOTE] = anon_sym_BQUOTE,
  [aux_sym_string_token4] = aux_sym_string_token4,
  [sym_number] = sym_number,
  [sym_identifier] = sym_identifier,
  [sym_comment] = sym_comment,
  [sym_source_file] = sym_source_file,
  [sym__statement] = sym__statement,
  [sym_variable_declaration] = sym_variable_declaration,
  [sym_lexical_declaration] = sym_lexical_declaration,
  [sym_variable_declarator] = sym_variable_declarator,
  [sym__initializer] = sym__initializer,
  [sym_assignment] = sym_assignment,
  [sym_function_call] = sym_function_call,
  [sym_method_call] = sym_method_call,
  [sym_chained_method] = sym_chained_method,
  [sym_binary_expression] = sym_binary_expression,
  [sym_additive_expression] = sym_additive_expression,
  [sym_multiplicative_expression] = sym_multiplicative_expression,
  [sym_arrow_function] = sym_arrow_function,
  [sym_expression] = sym_expression,
  [sym__base_expression] = sym__base_expression,
  [sym_object] = sym_object,
  [sym_pair] = sym_pair,
  [sym_array] = sym_array,
  [sym_string] = sym_string,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_variable_declaration_repeat1] = aux_sym_variable_declaration_repeat1,
  [aux_sym_function_call_repeat1] = aux_sym_function_call_repeat1,
  [aux_sym_chained_method_repeat1] = aux_sym_chained_method_repeat1,
  [aux_sym_object_repeat1] = aux_sym_object_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_string_repeat2] = aux_sym_string_repeat2,
  [aux_sym_string_repeat3] = aux_sym_string_repeat3,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_var] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_BQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_token4] = {
    .visible = false,
    .named = false,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_lexical_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym__initializer] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_method_call] = {
    .visible = true,
    .named = true,
  },
  [sym_chained_method] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_additive_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_multiplicative_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_arrow_function] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__base_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_object] = {
    .visible = true,
    .named = true,
  },
  [sym_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_array] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_call_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_chained_method_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat3] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_body = 1,
  field_key = 2,
  field_kind = 3,
  field_name = 4,
  field_operator = 5,
  field_parameter = 6,
  field_value = 7,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_body] = "body",
  [field_key] = "key",
  [field_kind] = "kind",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_parameter] = "parameter",
  [field_value] = "value",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 2},
  [4] = {.index = 4, .length = 2},
  [5] = {.index = 6, .length = 1},
  [6] = {.index = 7, .length = 1},
  [7] = {.index = 8, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 0},
  [1] =
    {field_kind, 0},
  [2] =
    {field_name, 0},
    {field_value, 1, .inherited = true},
  [4] =
    {field_body, 2},
    {field_parameter, 0},
  [6] =
    {field_operator, 1},
  [7] =
    {field_value, 1},
  [8] =
    {field_key, 0},
    {field_value, 2},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 6,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 7,
  [28] = 28,
  [29] = 19,
  [30] = 21,
  [31] = 23,
  [32] = 25,
  [33] = 26,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 35,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 45,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 52,
  [63] = 58,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 4,
  [76] = 5,
  [77] = 9,
  [78] = 15,
  [79] = 28,
  [80] = 8,
  [81] = 13,
  [82] = 14,
  [83] = 12,
  [84] = 16,
  [85] = 43,
  [86] = 17,
  [87] = 18,
  [88] = 20,
  [89] = 22,
  [90] = 24,
  [91] = 91,
  [92] = 44,
  [93] = 36,
  [94] = 91,
  [95] = 34,
  [96] = 41,
  [97] = 49,
  [98] = 48,
  [99] = 99,
  [100] = 57,
  [101] = 51,
  [102] = 60,
  [103] = 61,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 67,
  [108] = 108,
  [109] = 65,
  [110] = 110,
  [111] = 111,
  [112] = 105,
  [113] = 108,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 114,
  [119] = 115,
  [120] = 116,
  [121] = 117,
  [122] = 122,
  [123] = 123,
  [124] = 122,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 126,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 125,
  [134] = 134,
  [135] = 127,
  [136] = 128,
  [137] = 123,
  [138] = 134,
  [139] = 132,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 146,
  [149] = 149,
  [150] = 150,
  [151] = 149,
  [152] = 147,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(12);
      ADVANCE_MAP(
        '"', 34,
        '$', 6,
        '\'', 39,
        '(', 22,
        ')', 23,
        '*', 27,
        '+', 25,
        ',', 14,
        '-', 26,
        '.', 24,
        '/', 28,
        ':', 21,
        ';', 15,
        '=', 19,
        '[', 32,
        '\\', 9,
        ']', 33,
        '`', 43,
        'c', 52,
        'l', 50,
        'v', 49,
        '{', 30,
        '}', 31,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(47);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(1);
      if (lookahead == '/') ADVANCE(45);
      if (lookahead == '\\') ADVANCE(9);
      if (lookahead == '`') ADVANCE(43);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(46);
      if (lookahead != 0) ADVANCE(44);
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(2);
      if (lookahead == '"') ADVANCE(34);
      if (lookahead == '/') ADVANCE(36);
      if (lookahead == '\\') ADVANCE(9);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(37);
      if (lookahead != 0) ADVANCE(35);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(3);
      if (lookahead == '\'') ADVANCE(39);
      if (lookahead == '/') ADVANCE(41);
      if (lookahead == '\\') ADVANCE(9);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(42);
      if (lookahead != 0) ADVANCE(40);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '"', 34,
        '\'', 39,
        '(', 22,
        ')', 23,
        '.', 8,
        '/', 5,
        '[', 32,
        ']', 33,
        '`', 43,
        '{', 30,
        '}', 31,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(47);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 5:
      if (lookahead == '/') ADVANCE(58);
      END_STATE();
    case 6:
      if (lookahead == ':') ADVANCE(20);
      END_STATE();
    case 7:
      if (lookahead == '>') ADVANCE(29);
      END_STATE();
    case 8:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(48);
      END_STATE();
    case 9:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(38);
      END_STATE();
    case 10:
      if (eof) ADVANCE(12);
      ADVANCE_MAP(
        '"', 34,
        '$', 6,
        '\'', 39,
        '(', 22,
        ')', 23,
        '*', 27,
        '+', 25,
        ',', 14,
        '-', 26,
        '.', 24,
        '/', 28,
        ':', 21,
        ';', 15,
        '=', 7,
        '[', 32,
        ']', 33,
        '`', 43,
        'c', 52,
        'l', 50,
        'v', 49,
        '{', 30,
        '}', 31,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(47);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 11:
      if (eof) ADVANCE(12);
      ADVANCE_MAP(
        '"', 34,
        '$', 6,
        '\'', 39,
        '(', 22,
        ',', 14,
        '.', 8,
        '/', 5,
        ';', 15,
        '=', 18,
        '[', 32,
        '`', 43,
        'c', 52,
        'l', 50,
        'v', 49,
        '{', 30,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(47);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 12:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 13:
      ACCEPT_TOKEN(anon_sym_var);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 14:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 15:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 16:
      ACCEPT_TOKEN(anon_sym_let);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 17:
      ACCEPT_TOKEN(anon_sym_const);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 18:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 19:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(29);
      END_STATE();
    case 20:
      ACCEPT_TOKEN(anon_sym_DOLLAR_COLON);
      END_STATE();
    case 21:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 22:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 24:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(48);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(58);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(aux_sym_string_token1);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead == '/') ADVANCE(58);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead == '/') ADVANCE(36);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(37);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(35);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(aux_sym_string_token2);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(aux_sym_string_token3);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(aux_sym_string_token3);
      if (lookahead == '/') ADVANCE(58);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(aux_sym_string_token3);
      if (lookahead == '/') ADVANCE(41);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(42);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(40);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(aux_sym_string_token4);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(aux_sym_string_token4);
      if (lookahead == '/') ADVANCE(58);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(aux_sym_string_token4);
      if (lookahead == '/') ADVANCE(45);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(46);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '\\' &&
          lookahead != '`') ADVANCE(44);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.') ADVANCE(8);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(47);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(sym_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(48);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(53);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(55);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(54);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(51);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(13);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(56);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(16);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(17);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(58);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 0},
  [2] = {.lex_state = 0},
  [3] = {.lex_state = 0},
  [4] = {.lex_state = 0},
  [5] = {.lex_state = 10},
  [6] = {.lex_state = 4},
  [7] = {.lex_state = 4},
  [8] = {.lex_state = 0},
  [9] = {.lex_state = 0},
  [10] = {.lex_state = 4},
  [11] = {.lex_state = 10},
  [12] = {.lex_state = 0},
  [13] = {.lex_state = 0},
  [14] = {.lex_state = 0},
  [15] = {.lex_state = 0},
  [16] = {.lex_state = 0},
  [17] = {.lex_state = 0},
  [18] = {.lex_state = 0},
  [19] = {.lex_state = 4},
  [20] = {.lex_state = 0},
  [21] = {.lex_state = 4},
  [22] = {.lex_state = 0},
  [23] = {.lex_state = 4},
  [24] = {.lex_state = 0},
  [25] = {.lex_state = 4},
  [26] = {.lex_state = 4},
  [27] = {.lex_state = 4},
  [28] = {.lex_state = 0},
  [29] = {.lex_state = 4},
  [30] = {.lex_state = 4},
  [31] = {.lex_state = 4},
  [32] = {.lex_state = 4},
  [33] = {.lex_state = 4},
  [34] = {.lex_state = 0},
  [35] = {.lex_state = 4},
  [36] = {.lex_state = 0},
  [37] = {.lex_state = 4},
  [38] = {.lex_state = 4},
  [39] = {.lex_state = 4},
  [40] = {.lex_state = 4},
  [41] = {.lex_state = 0},
  [42] = {.lex_state = 4},
  [43] = {.lex_state = 0},
  [44] = {.lex_state = 0},
  [45] = {.lex_state = 4},
  [46] = {.lex_state = 4},
  [47] = {.lex_state = 4},
  [48] = {.lex_state = 0},
  [49] = {.lex_state = 0},
  [50] = {.lex_state = 11},
  [51] = {.lex_state = 0},
  [52] = {.lex_state = 4},
  [53] = {.lex_state = 0},
  [54] = {.lex_state = 0},
  [55] = {.lex_state = 0},
  [56] = {.lex_state = 0},
  [57] = {.lex_state = 0},
  [58] = {.lex_state = 4},
  [59] = {.lex_state = 0},
  [60] = {.lex_state = 0},
  [61] = {.lex_state = 0},
  [62] = {.lex_state = 4},
  [63] = {.lex_state = 4},
  [64] = {.lex_state = 0},
  [65] = {.lex_state = 0},
  [66] = {.lex_state = 0},
  [67] = {.lex_state = 0},
  [68] = {.lex_state = 0},
  [69] = {.lex_state = 0},
  [70] = {.lex_state = 0},
  [71] = {.lex_state = 0},
  [72] = {.lex_state = 0},
  [73] = {.lex_state = 0},
  [74] = {.lex_state = 0},
  [75] = {.lex_state = 0},
  [76] = {.lex_state = 10},
  [77] = {.lex_state = 0},
  [78] = {.lex_state = 0},
  [79] = {.lex_state = 0},
  [80] = {.lex_state = 0},
  [81] = {.lex_state = 0},
  [82] = {.lex_state = 0},
  [83] = {.lex_state = 0},
  [84] = {.lex_state = 0},
  [85] = {.lex_state = 0},
  [86] = {.lex_state = 0},
  [87] = {.lex_state = 0},
  [88] = {.lex_state = 0},
  [89] = {.lex_state = 0},
  [90] = {.lex_state = 0},
  [91] = {.lex_state = 4},
  [92] = {.lex_state = 0},
  [93] = {.lex_state = 0},
  [94] = {.lex_state = 4},
  [95] = {.lex_state = 0},
  [96] = {.lex_state = 0},
  [97] = {.lex_state = 0},
  [98] = {.lex_state = 0},
  [99] = {.lex_state = 4},
  [100] = {.lex_state = 0},
  [101] = {.lex_state = 0},
  [102] = {.lex_state = 0},
  [103] = {.lex_state = 0},
  [104] = {.lex_state = 1},
  [105] = {.lex_state = 2},
  [106] = {.lex_state = 2},
  [107] = {.lex_state = 0},
  [108] = {.lex_state = 3},
  [109] = {.lex_state = 0},
  [110] = {.lex_state = 3},
  [111] = {.lex_state = 0},
  [112] = {.lex_state = 2},
  [113] = {.lex_state = 3},
  [114] = {.lex_state = 1},
  [115] = {.lex_state = 2},
  [116] = {.lex_state = 3},
  [117] = {.lex_state = 1},
  [118] = {.lex_state = 1},
  [119] = {.lex_state = 2},
  [120] = {.lex_state = 3},
  [121] = {.lex_state = 1},
  [122] = {.lex_state = 0},
  [123] = {.lex_state = 0},
  [124] = {.lex_state = 0},
  [125] = {.lex_state = 0},
  [126] = {.lex_state = 0},
  [127] = {.lex_state = 0},
  [128] = {.lex_state = 0},
  [129] = {.lex_state = 0},
  [130] = {.lex_state = 0},
  [131] = {.lex_state = 0},
  [132] = {.lex_state = 0},
  [133] = {.lex_state = 0},
  [134] = {.lex_state = 0},
  [135] = {.lex_state = 0},
  [136] = {.lex_state = 0},
  [137] = {.lex_state = 0},
  [138] = {.lex_state = 0},
  [139] = {.lex_state = 0},
  [140] = {.lex_state = 4},
  [141] = {.lex_state = 0},
  [142] = {.lex_state = 4},
  [143] = {.lex_state = 0},
  [144] = {.lex_state = 4},
  [145] = {.lex_state = 0},
  [146] = {.lex_state = 0},
  [147] = {.lex_state = 4},
  [148] = {.lex_state = 0},
  [149] = {.lex_state = 0},
  [150] = {.lex_state = 0},
  [151] = {.lex_state = 0},
  [152] = {.lex_state = 4},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_var] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_let] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_DOLLAR_COLON] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [aux_sym_string_token2] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_BQUOTE] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(145),
    [sym__statement] = STATE(2),
    [sym_variable_declaration] = STATE(2),
    [sym_lexical_declaration] = STATE(2),
    [sym_assignment] = STATE(2),
    [sym_function_call] = STATE(4),
    [sym_chained_method] = STATE(65),
    [sym_binary_expression] = STATE(34),
    [sym_additive_expression] = STATE(41),
    [sym_multiplicative_expression] = STATE(41),
    [sym_arrow_function] = STATE(65),
    [sym_expression] = STATE(2),
    [sym__base_expression] = STATE(4),
    [sym_object] = STATE(4),
    [sym_array] = STATE(4),
    [sym_string] = STATE(4),
    [aux_sym_source_file_repeat1] = STATE(2),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_var] = ACTIONS(7),
    [anon_sym_let] = ACTIONS(9),
    [anon_sym_const] = ACTIONS(9),
    [anon_sym_DOLLAR_COLON] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_DQUOTE] = ACTIONS(19),
    [anon_sym_SQUOTE] = ACTIONS(21),
    [anon_sym_BQUOTE] = ACTIONS(23),
    [sym_number] = ACTIONS(25),
    [sym_identifier] = ACTIONS(27),
    [sym_comment] = ACTIONS(29),
  },
  [STATE(2)] = {
    [sym__statement] = STATE(3),
    [sym_variable_declaration] = STATE(3),
    [sym_lexical_declaration] = STATE(3),
    [sym_assignment] = STATE(3),
    [sym_function_call] = STATE(4),
    [sym_chained_method] = STATE(65),
    [sym_binary_expression] = STATE(34),
    [sym_additive_expression] = STATE(41),
    [sym_multiplicative_expression] = STATE(41),
    [sym_arrow_function] = STATE(65),
    [sym_expression] = STATE(3),
    [sym__base_expression] = STATE(4),
    [sym_object] = STATE(4),
    [sym_array] = STATE(4),
    [sym_string] = STATE(4),
    [aux_sym_source_file_repeat1] = STATE(3),
    [ts_builtin_sym_end] = ACTIONS(31),
    [anon_sym_var] = ACTIONS(7),
    [anon_sym_let] = ACTIONS(9),
    [anon_sym_const] = ACTIONS(9),
    [anon_sym_DOLLAR_COLON] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(13),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_DQUOTE] = ACTIONS(19),
    [anon_sym_SQUOTE] = ACTIONS(21),
    [anon_sym_BQUOTE] = ACTIONS(23),
    [sym_number] = ACTIONS(25),
    [sym_identifier] = ACTIONS(27),
    [sym_comment] = ACTIONS(33),
  },
  [STATE(3)] = {
    [sym__statement] = STATE(3),
    [sym_variable_declaration] = STATE(3),
    [sym_lexical_declaration] = STATE(3),
    [sym_assignment] = STATE(3),
    [sym_function_call] = STATE(4),
    [sym_chained_method] = STATE(65),
    [sym_binary_expression] = STATE(34),
    [sym_additive_expression] = STATE(41),
    [sym_multiplicative_expression] = STATE(41),
    [sym_arrow_function] = STATE(65),
    [sym_expression] = STATE(3),
    [sym__base_expression] = STATE(4),
    [sym_object] = STATE(4),
    [sym_array] = STATE(4),
    [sym_string] = STATE(4),
    [aux_sym_source_file_repeat1] = STATE(3),
    [ts_builtin_sym_end] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(37),
    [anon_sym_let] = ACTIONS(40),
    [anon_sym_const] = ACTIONS(40),
    [anon_sym_DOLLAR_COLON] = ACTIONS(43),
    [anon_sym_LPAREN] = ACTIONS(46),
    [anon_sym_LBRACE] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(52),
    [anon_sym_DQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(58),
    [anon_sym_BQUOTE] = ACTIONS(61),
    [sym_number] = ACTIONS(64),
    [sym_identifier] = ACTIONS(67),
    [sym_comment] = ACTIONS(70),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 6,
    ACTIONS(77), 1,
      anon_sym_DOT,
    ACTIONS(81), 1,
      anon_sym_SLASH,
    STATE(48), 2,
      sym_method_call,
      aux_sym_chained_method_repeat1,
    ACTIONS(79), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
    ACTIONS(75), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(73), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [36] = 4,
    ACTIONS(87), 1,
      anon_sym_LPAREN,
    ACTIONS(89), 1,
      anon_sym_EQ_GT,
    ACTIONS(85), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(83), 14,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [67] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(93), 1,
      anon_sym_RPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    STATE(95), 1,
      sym_binary_expression,
    STATE(135), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [119] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(109), 1,
      anon_sym_RBRACK,
    STATE(95), 1,
      sym_binary_expression,
    STATE(122), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [171] = 2,
    ACTIONS(113), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(111), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [197] = 2,
    ACTIONS(117), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(115), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [223] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(119), 1,
      anon_sym_RPAREN,
    STATE(95), 1,
      sym_binary_expression,
    STATE(127), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [275] = 5,
    ACTIONS(87), 1,
      anon_sym_LPAREN,
    ACTIONS(89), 1,
      anon_sym_EQ_GT,
    ACTIONS(121), 1,
      anon_sym_COLON,
    ACTIONS(85), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(83), 12,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [307] = 2,
    ACTIONS(125), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(123), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [333] = 2,
    ACTIONS(129), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(127), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [359] = 2,
    ACTIONS(133), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(131), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [385] = 2,
    ACTIONS(137), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(135), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [411] = 2,
    ACTIONS(141), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(139), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [437] = 2,
    ACTIONS(145), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(143), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [463] = 2,
    ACTIONS(149), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(147), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [489] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(151), 1,
      anon_sym_RPAREN,
    STATE(95), 1,
      sym_binary_expression,
    STATE(131), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [541] = 2,
    ACTIONS(155), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(153), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [567] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_RPAREN,
    STATE(95), 1,
      sym_binary_expression,
    STATE(128), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [619] = 2,
    ACTIONS(161), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(159), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [645] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(163), 1,
      anon_sym_RPAREN,
    STATE(95), 1,
      sym_binary_expression,
    STATE(131), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [697] = 2,
    ACTIONS(167), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(165), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [723] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(169), 1,
      anon_sym_RPAREN,
    STATE(95), 1,
      sym_binary_expression,
    STATE(131), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [775] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(171), 1,
      anon_sym_RPAREN,
    STATE(95), 1,
      sym_binary_expression,
    STATE(131), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [827] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(173), 1,
      anon_sym_RBRACK,
    STATE(95), 1,
      sym_binary_expression,
    STATE(124), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [879] = 2,
    ACTIONS(177), 6,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(175), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [905] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(179), 1,
      anon_sym_RPAREN,
    STATE(95), 1,
      sym_binary_expression,
    STATE(131), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [957] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_RPAREN,
    STATE(95), 1,
      sym_binary_expression,
    STATE(136), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1009] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(183), 1,
      anon_sym_RPAREN,
    STATE(95), 1,
      sym_binary_expression,
    STATE(131), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1061] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(185), 1,
      anon_sym_RPAREN,
    STATE(95), 1,
      sym_binary_expression,
    STATE(131), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1113] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    ACTIONS(187), 1,
      anon_sym_RPAREN,
    STATE(95), 1,
      sym_binary_expression,
    STATE(131), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1165] = 5,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_SLASH,
    ACTIONS(189), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(75), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(73), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1196] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    STATE(95), 1,
      sym_binary_expression,
    STATE(148), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1245] = 2,
    ACTIONS(197), 5,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(195), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1270] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_DQUOTE,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    ACTIONS(23), 1,
      anon_sym_BQUOTE,
    ACTIONS(25), 1,
      sym_number,
    ACTIONS(199), 1,
      sym_identifier,
    STATE(34), 1,
      sym_binary_expression,
    STATE(64), 1,
      sym_expression,
    STATE(41), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(65), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(4), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1319] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    STATE(95), 1,
      sym_binary_expression,
    STATE(143), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1368] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_DQUOTE,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    ACTIONS(23), 1,
      anon_sym_BQUOTE,
    ACTIONS(25), 1,
      sym_number,
    ACTIONS(199), 1,
      sym_identifier,
    STATE(34), 1,
      sym_binary_expression,
    STATE(69), 1,
      sym_expression,
    STATE(41), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(65), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(4), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1417] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    STATE(95), 1,
      sym_binary_expression,
    STATE(131), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1466] = 2,
    ACTIONS(81), 5,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(79), 15,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1491] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    STATE(95), 1,
      sym_binary_expression,
    STATE(146), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1540] = 3,
    ACTIONS(87), 1,
      anon_sym_LPAREN,
    ACTIONS(85), 5,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(83), 14,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1567] = 4,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_SLASH,
    ACTIONS(203), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(201), 14,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1596] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_DQUOTE,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    ACTIONS(23), 1,
      anon_sym_BQUOTE,
    ACTIONS(25), 1,
      sym_number,
    ACTIONS(199), 1,
      sym_identifier,
    STATE(34), 1,
      sym_binary_expression,
    STATE(67), 1,
      sym_expression,
    STATE(41), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(65), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(4), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1645] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(105), 1,
      sym_number,
    ACTIONS(107), 1,
      sym_identifier,
    STATE(95), 1,
      sym_binary_expression,
    STATE(107), 1,
      sym_expression,
    STATE(96), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(109), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(75), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1694] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_DQUOTE,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    ACTIONS(23), 1,
      anon_sym_BQUOTE,
    ACTIONS(25), 1,
      sym_number,
    ACTIONS(199), 1,
      sym_identifier,
    STATE(34), 1,
      sym_binary_expression,
    STATE(70), 1,
      sym_expression,
    STATE(41), 2,
      sym_additive_expression,
      sym_multiplicative_expression,
    STATE(65), 2,
      sym_chained_method,
      sym_arrow_function,
    STATE(4), 5,
      sym_function_call,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1743] = 4,
    ACTIONS(77), 1,
      anon_sym_DOT,
    STATE(49), 2,
      sym_method_call,
      aux_sym_chained_method_repeat1,
    ACTIONS(207), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(205), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1771] = 4,
    ACTIONS(213), 1,
      anon_sym_DOT,
    STATE(49), 2,
      sym_method_call,
      aux_sym_chained_method_repeat1,
    ACTIONS(211), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(209), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1799] = 4,
    ACTIONS(220), 1,
      anon_sym_EQ,
    STATE(66), 1,
      sym__initializer,
    ACTIONS(218), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(216), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1826] = 2,
    ACTIONS(224), 5,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(222), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1848] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_DQUOTE,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    ACTIONS(23), 1,
      anon_sym_BQUOTE,
    ACTIONS(226), 1,
      sym_number,
    ACTIONS(228), 1,
      sym_identifier,
    STATE(44), 1,
      sym_binary_expression,
    STATE(41), 7,
      sym_function_call,
      sym_additive_expression,
      sym_multiplicative_expression,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [1888] = 4,
    ACTIONS(234), 1,
      anon_sym_COMMA,
    STATE(53), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(232), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(230), 11,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1914] = 5,
    ACTIONS(241), 1,
      anon_sym_COMMA,
    ACTIONS(243), 1,
      anon_sym_SEMI,
    STATE(53), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(239), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(237), 10,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1942] = 5,
    ACTIONS(241), 1,
      anon_sym_COMMA,
    ACTIONS(249), 1,
      anon_sym_SEMI,
    STATE(53), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(247), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(245), 10,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1970] = 5,
    ACTIONS(241), 1,
      anon_sym_COMMA,
    ACTIONS(255), 1,
      anon_sym_SEMI,
    STATE(55), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(253), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(251), 10,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [1998] = 2,
    ACTIONS(259), 5,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(257), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2020] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_DQUOTE,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    ACTIONS(23), 1,
      anon_sym_BQUOTE,
    ACTIONS(226), 1,
      sym_number,
    ACTIONS(228), 1,
      sym_identifier,
    STATE(36), 1,
      sym_binary_expression,
    STATE(41), 7,
      sym_function_call,
      sym_additive_expression,
      sym_multiplicative_expression,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [2060] = 5,
    ACTIONS(241), 1,
      anon_sym_COMMA,
    ACTIONS(265), 1,
      anon_sym_SEMI,
    STATE(54), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(263), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(261), 10,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2088] = 2,
    ACTIONS(269), 5,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(267), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2110] = 2,
    ACTIONS(273), 5,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(271), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2132] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(275), 1,
      sym_number,
    ACTIONS(277), 1,
      sym_identifier,
    STATE(92), 1,
      sym_binary_expression,
    STATE(96), 7,
      sym_function_call,
      sym_additive_expression,
      sym_multiplicative_expression,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [2172] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      anon_sym_LPAREN,
    ACTIONS(95), 1,
      anon_sym_LBRACE,
    ACTIONS(97), 1,
      anon_sym_LBRACK,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(275), 1,
      sym_number,
    ACTIONS(277), 1,
      sym_identifier,
    STATE(93), 1,
      sym_binary_expression,
    STATE(96), 7,
      sym_function_call,
      sym_additive_expression,
      sym_multiplicative_expression,
      sym__base_expression,
      sym_object,
      sym_array,
      sym_string,
  [2212] = 2,
    ACTIONS(281), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(279), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2233] = 2,
    ACTIONS(75), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(73), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2254] = 2,
    ACTIONS(285), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(283), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2275] = 2,
    ACTIONS(289), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(287), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2296] = 2,
    ACTIONS(232), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(230), 12,
      ts_builtin_sym_end,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2317] = 2,
    ACTIONS(293), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(291), 10,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2336] = 2,
    ACTIONS(297), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(295), 10,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2355] = 2,
    ACTIONS(247), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(245), 10,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2374] = 2,
    ACTIONS(301), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(299), 10,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2393] = 2,
    ACTIONS(239), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(237), 10,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2412] = 2,
    ACTIONS(305), 4,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      sym_identifier,
    ACTIONS(303), 10,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_BQUOTE,
      sym_number,
      sym_comment,
  [2431] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(81), 1,
      anon_sym_SLASH,
    ACTIONS(307), 1,
      anon_sym_DOT,
    STATE(98), 2,
      sym_method_call,
      aux_sym_chained_method_repeat1,
    ACTIONS(79), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
    ACTIONS(73), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2456] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(85), 1,
      anon_sym_SLASH,
    ACTIONS(309), 1,
      anon_sym_LPAREN,
    ACTIONS(311), 1,
      anon_sym_EQ_GT,
    ACTIONS(83), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2479] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      anon_sym_SLASH,
    ACTIONS(115), 9,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2497] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(137), 1,
      anon_sym_SLASH,
    ACTIONS(135), 9,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2515] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(177), 1,
      anon_sym_SLASH,
    ACTIONS(175), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2532] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 1,
      anon_sym_SLASH,
    ACTIONS(111), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2549] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(129), 1,
      anon_sym_SLASH,
    ACTIONS(127), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2566] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(133), 1,
      anon_sym_SLASH,
    ACTIONS(131), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      anon_sym_SLASH,
    ACTIONS(123), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(141), 1,
      anon_sym_SLASH,
    ACTIONS(139), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2617] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(85), 1,
      anon_sym_SLASH,
    ACTIONS(309), 1,
      anon_sym_LPAREN,
    ACTIONS(83), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2636] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(145), 1,
      anon_sym_SLASH,
    ACTIONS(143), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2653] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(149), 1,
      anon_sym_SLASH,
    ACTIONS(147), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2670] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(155), 1,
      anon_sym_SLASH,
    ACTIONS(153), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2687] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(161), 1,
      anon_sym_SLASH,
    ACTIONS(159), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2704] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(167), 1,
      anon_sym_SLASH,
    ACTIONS(165), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2721] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(313), 1,
      anon_sym_RBRACE,
    STATE(129), 1,
      sym_pair,
    STATE(150), 1,
      sym_string,
    ACTIONS(315), 2,
      sym_number,
      sym_identifier,
  [2747] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(317), 1,
      anon_sym_STAR,
    ACTIONS(319), 1,
      anon_sym_SLASH,
    ACTIONS(201), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2765] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(197), 1,
      anon_sym_SLASH,
    ACTIONS(195), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2781] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    ACTIONS(321), 1,
      anon_sym_RBRACE,
    STATE(126), 1,
      sym_pair,
    STATE(150), 1,
      sym_string,
    ACTIONS(315), 2,
      sym_number,
      sym_identifier,
  [2807] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(317), 1,
      anon_sym_STAR,
    ACTIONS(319), 1,
      anon_sym_SLASH,
    ACTIONS(323), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(73), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2827] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(81), 1,
      anon_sym_SLASH,
    ACTIONS(79), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2843] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(325), 1,
      anon_sym_DOT,
    STATE(97), 2,
      sym_method_call,
      aux_sym_chained_method_repeat1,
    ACTIONS(209), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2860] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(307), 1,
      anon_sym_DOT,
    STATE(97), 2,
      sym_method_call,
      aux_sym_chained_method_repeat1,
    ACTIONS(205), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2877] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    ACTIONS(101), 1,
      anon_sym_SQUOTE,
    ACTIONS(103), 1,
      anon_sym_BQUOTE,
    STATE(141), 1,
      sym_pair,
    STATE(150), 1,
      sym_string,
    ACTIONS(315), 2,
      sym_number,
      sym_identifier,
  [2900] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(257), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2911] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(222), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2922] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(267), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2933] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(271), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2944] = 4,
    ACTIONS(331), 1,
      anon_sym_BQUOTE,
    ACTIONS(333), 1,
      sym_comment,
    STATE(104), 1,
      aux_sym_string_repeat3,
    ACTIONS(328), 2,
      aux_sym_string_token2,
      aux_sym_string_token4,
  [2958] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(335), 1,
      anon_sym_DQUOTE,
    STATE(119), 1,
      aux_sym_string_repeat1,
    ACTIONS(337), 2,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [2972] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(339), 1,
      anon_sym_DQUOTE,
    STATE(106), 1,
      aux_sym_string_repeat1,
    ACTIONS(341), 2,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [2986] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(287), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [2996] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(335), 1,
      anon_sym_SQUOTE,
    STATE(120), 1,
      aux_sym_string_repeat2,
    ACTIONS(344), 2,
      aux_sym_string_token2,
      aux_sym_string_token3,
  [3010] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
  [3020] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(349), 1,
      anon_sym_SQUOTE,
    STATE(110), 1,
      aux_sym_string_repeat2,
    ACTIONS(346), 2,
      aux_sym_string_token2,
      aux_sym_string_token3,
  [3034] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(351), 1,
      anon_sym_COMMA,
    STATE(111), 1,
      aux_sym_function_call_repeat1,
    ACTIONS(354), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [3048] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(356), 1,
      anon_sym_DQUOTE,
    STATE(115), 1,
      aux_sym_string_repeat1,
    ACTIONS(358), 2,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [3062] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(356), 1,
      anon_sym_SQUOTE,
    STATE(116), 1,
      aux_sym_string_repeat2,
    ACTIONS(360), 2,
      aux_sym_string_token2,
      aux_sym_string_token3,
  [3076] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(356), 1,
      anon_sym_BQUOTE,
    STATE(117), 1,
      aux_sym_string_repeat3,
    ACTIONS(362), 2,
      aux_sym_string_token2,
      aux_sym_string_token4,
  [3090] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(364), 1,
      anon_sym_DQUOTE,
    STATE(106), 1,
      aux_sym_string_repeat1,
    ACTIONS(366), 2,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [3104] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(364), 1,
      anon_sym_SQUOTE,
    STATE(110), 1,
      aux_sym_string_repeat2,
    ACTIONS(368), 2,
      aux_sym_string_token2,
      aux_sym_string_token3,
  [3118] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(364), 1,
      anon_sym_BQUOTE,
    STATE(104), 1,
      aux_sym_string_repeat3,
    ACTIONS(370), 2,
      aux_sym_string_token2,
      aux_sym_string_token4,
  [3132] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(335), 1,
      anon_sym_BQUOTE,
    STATE(121), 1,
      aux_sym_string_repeat3,
    ACTIONS(372), 2,
      aux_sym_string_token2,
      aux_sym_string_token4,
  [3146] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(374), 1,
      anon_sym_DQUOTE,
    STATE(106), 1,
      aux_sym_string_repeat1,
    ACTIONS(366), 2,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [3160] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(374), 1,
      anon_sym_SQUOTE,
    STATE(110), 1,
      aux_sym_string_repeat2,
    ACTIONS(368), 2,
      aux_sym_string_token2,
      aux_sym_string_token3,
  [3174] = 4,
    ACTIONS(333), 1,
      sym_comment,
    ACTIONS(374), 1,
      anon_sym_BQUOTE,
    STATE(104), 1,
      aux_sym_string_repeat3,
    ACTIONS(370), 2,
      aux_sym_string_token2,
      aux_sym_string_token4,
  [3188] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(376), 1,
      anon_sym_COMMA,
    ACTIONS(378), 1,
      anon_sym_RBRACK,
    STATE(138), 1,
      aux_sym_function_call_repeat1,
  [3201] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(151), 1,
      anon_sym_RPAREN,
    ACTIONS(380), 1,
      anon_sym_COMMA,
    STATE(111), 1,
      aux_sym_function_call_repeat1,
  [3214] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(376), 1,
      anon_sym_COMMA,
    ACTIONS(382), 1,
      anon_sym_RBRACK,
    STATE(134), 1,
      aux_sym_function_call_repeat1,
  [3227] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(384), 1,
      anon_sym_COMMA,
    ACTIONS(386), 1,
      anon_sym_RBRACE,
    STATE(130), 1,
      aux_sym_object_repeat1,
  [3240] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(384), 1,
      anon_sym_COMMA,
    ACTIONS(388), 1,
      anon_sym_RBRACE,
    STATE(125), 1,
      aux_sym_object_repeat1,
  [3253] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(390), 1,
      anon_sym_COMMA,
    ACTIONS(392), 1,
      anon_sym_RPAREN,
    STATE(123), 1,
      aux_sym_function_call_repeat1,
  [3266] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(394), 1,
      anon_sym_COMMA,
    ACTIONS(396), 1,
      anon_sym_RPAREN,
    STATE(132), 1,
      aux_sym_function_call_repeat1,
  [3279] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(384), 1,
      anon_sym_COMMA,
    ACTIONS(398), 1,
      anon_sym_RBRACE,
    STATE(133), 1,
      aux_sym_object_repeat1,
  [3292] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(400), 1,
      anon_sym_COMMA,
    ACTIONS(403), 1,
      anon_sym_RBRACE,
    STATE(130), 1,
      aux_sym_object_repeat1,
  [3305] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(354), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [3314] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(169), 1,
      anon_sym_RPAREN,
    ACTIONS(405), 1,
      anon_sym_COMMA,
    STATE(111), 1,
      aux_sym_function_call_repeat1,
  [3327] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(384), 1,
      anon_sym_COMMA,
    ACTIONS(407), 1,
      anon_sym_RBRACE,
    STATE(130), 1,
      aux_sym_object_repeat1,
  [3340] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(376), 1,
      anon_sym_COMMA,
    ACTIONS(409), 1,
      anon_sym_RBRACK,
    STATE(111), 1,
      aux_sym_function_call_repeat1,
  [3353] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(411), 1,
      anon_sym_COMMA,
    ACTIONS(413), 1,
      anon_sym_RPAREN,
    STATE(137), 1,
      aux_sym_function_call_repeat1,
  [3366] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      anon_sym_COMMA,
    ACTIONS(417), 1,
      anon_sym_RPAREN,
    STATE(139), 1,
      aux_sym_function_call_repeat1,
  [3379] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(179), 1,
      anon_sym_RPAREN,
    ACTIONS(419), 1,
      anon_sym_COMMA,
    STATE(111), 1,
      aux_sym_function_call_repeat1,
  [3392] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(376), 1,
      anon_sym_COMMA,
    ACTIONS(421), 1,
      anon_sym_RBRACK,
    STATE(111), 1,
      aux_sym_function_call_repeat1,
  [3405] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_RPAREN,
    ACTIONS(423), 1,
      anon_sym_COMMA,
    STATE(111), 1,
      aux_sym_function_call_repeat1,
  [3418] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 1,
      sym_identifier,
    STATE(68), 1,
      sym_variable_declarator,
  [3428] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [3436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 1,
      sym_identifier,
    STATE(59), 1,
      sym_variable_declarator,
  [3446] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [3454] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 1,
      sym_identifier,
    STATE(56), 1,
      sym_variable_declarator,
  [3464] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      ts_builtin_sym_end,
  [3471] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 1,
      anon_sym_RPAREN,
  [3478] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 1,
      sym_identifier,
  [3485] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_RPAREN,
  [3492] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 1,
      anon_sym_LPAREN,
  [3499] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_COLON,
  [3506] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 1,
      anon_sym_LPAREN,
  [3513] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      sym_identifier,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(4)] = 0,
  [SMALL_STATE(5)] = 36,
  [SMALL_STATE(6)] = 67,
  [SMALL_STATE(7)] = 119,
  [SMALL_STATE(8)] = 171,
  [SMALL_STATE(9)] = 197,
  [SMALL_STATE(10)] = 223,
  [SMALL_STATE(11)] = 275,
  [SMALL_STATE(12)] = 307,
  [SMALL_STATE(13)] = 333,
  [SMALL_STATE(14)] = 359,
  [SMALL_STATE(15)] = 385,
  [SMALL_STATE(16)] = 411,
  [SMALL_STATE(17)] = 437,
  [SMALL_STATE(18)] = 463,
  [SMALL_STATE(19)] = 489,
  [SMALL_STATE(20)] = 541,
  [SMALL_STATE(21)] = 567,
  [SMALL_STATE(22)] = 619,
  [SMALL_STATE(23)] = 645,
  [SMALL_STATE(24)] = 697,
  [SMALL_STATE(25)] = 723,
  [SMALL_STATE(26)] = 775,
  [SMALL_STATE(27)] = 827,
  [SMALL_STATE(28)] = 879,
  [SMALL_STATE(29)] = 905,
  [SMALL_STATE(30)] = 957,
  [SMALL_STATE(31)] = 1009,
  [SMALL_STATE(32)] = 1061,
  [SMALL_STATE(33)] = 1113,
  [SMALL_STATE(34)] = 1165,
  [SMALL_STATE(35)] = 1196,
  [SMALL_STATE(36)] = 1245,
  [SMALL_STATE(37)] = 1270,
  [SMALL_STATE(38)] = 1319,
  [SMALL_STATE(39)] = 1368,
  [SMALL_STATE(40)] = 1417,
  [SMALL_STATE(41)] = 1466,
  [SMALL_STATE(42)] = 1491,
  [SMALL_STATE(43)] = 1540,
  [SMALL_STATE(44)] = 1567,
  [SMALL_STATE(45)] = 1596,
  [SMALL_STATE(46)] = 1645,
  [SMALL_STATE(47)] = 1694,
  [SMALL_STATE(48)] = 1743,
  [SMALL_STATE(49)] = 1771,
  [SMALL_STATE(50)] = 1799,
  [SMALL_STATE(51)] = 1826,
  [SMALL_STATE(52)] = 1848,
  [SMALL_STATE(53)] = 1888,
  [SMALL_STATE(54)] = 1914,
  [SMALL_STATE(55)] = 1942,
  [SMALL_STATE(56)] = 1970,
  [SMALL_STATE(57)] = 1998,
  [SMALL_STATE(58)] = 2020,
  [SMALL_STATE(59)] = 2060,
  [SMALL_STATE(60)] = 2088,
  [SMALL_STATE(61)] = 2110,
  [SMALL_STATE(62)] = 2132,
  [SMALL_STATE(63)] = 2172,
  [SMALL_STATE(64)] = 2212,
  [SMALL_STATE(65)] = 2233,
  [SMALL_STATE(66)] = 2254,
  [SMALL_STATE(67)] = 2275,
  [SMALL_STATE(68)] = 2296,
  [SMALL_STATE(69)] = 2317,
  [SMALL_STATE(70)] = 2336,
  [SMALL_STATE(71)] = 2355,
  [SMALL_STATE(72)] = 2374,
  [SMALL_STATE(73)] = 2393,
  [SMALL_STATE(74)] = 2412,
  [SMALL_STATE(75)] = 2431,
  [SMALL_STATE(76)] = 2456,
  [SMALL_STATE(77)] = 2479,
  [SMALL_STATE(78)] = 2497,
  [SMALL_STATE(79)] = 2515,
  [SMALL_STATE(80)] = 2532,
  [SMALL_STATE(81)] = 2549,
  [SMALL_STATE(82)] = 2566,
  [SMALL_STATE(83)] = 2583,
  [SMALL_STATE(84)] = 2600,
  [SMALL_STATE(85)] = 2617,
  [SMALL_STATE(86)] = 2636,
  [SMALL_STATE(87)] = 2653,
  [SMALL_STATE(88)] = 2670,
  [SMALL_STATE(89)] = 2687,
  [SMALL_STATE(90)] = 2704,
  [SMALL_STATE(91)] = 2721,
  [SMALL_STATE(92)] = 2747,
  [SMALL_STATE(93)] = 2765,
  [SMALL_STATE(94)] = 2781,
  [SMALL_STATE(95)] = 2807,
  [SMALL_STATE(96)] = 2827,
  [SMALL_STATE(97)] = 2843,
  [SMALL_STATE(98)] = 2860,
  [SMALL_STATE(99)] = 2877,
  [SMALL_STATE(100)] = 2900,
  [SMALL_STATE(101)] = 2911,
  [SMALL_STATE(102)] = 2922,
  [SMALL_STATE(103)] = 2933,
  [SMALL_STATE(104)] = 2944,
  [SMALL_STATE(105)] = 2958,
  [SMALL_STATE(106)] = 2972,
  [SMALL_STATE(107)] = 2986,
  [SMALL_STATE(108)] = 2996,
  [SMALL_STATE(109)] = 3010,
  [SMALL_STATE(110)] = 3020,
  [SMALL_STATE(111)] = 3034,
  [SMALL_STATE(112)] = 3048,
  [SMALL_STATE(113)] = 3062,
  [SMALL_STATE(114)] = 3076,
  [SMALL_STATE(115)] = 3090,
  [SMALL_STATE(116)] = 3104,
  [SMALL_STATE(117)] = 3118,
  [SMALL_STATE(118)] = 3132,
  [SMALL_STATE(119)] = 3146,
  [SMALL_STATE(120)] = 3160,
  [SMALL_STATE(121)] = 3174,
  [SMALL_STATE(122)] = 3188,
  [SMALL_STATE(123)] = 3201,
  [SMALL_STATE(124)] = 3214,
  [SMALL_STATE(125)] = 3227,
  [SMALL_STATE(126)] = 3240,
  [SMALL_STATE(127)] = 3253,
  [SMALL_STATE(128)] = 3266,
  [SMALL_STATE(129)] = 3279,
  [SMALL_STATE(130)] = 3292,
  [SMALL_STATE(131)] = 3305,
  [SMALL_STATE(132)] = 3314,
  [SMALL_STATE(133)] = 3327,
  [SMALL_STATE(134)] = 3340,
  [SMALL_STATE(135)] = 3353,
  [SMALL_STATE(136)] = 3366,
  [SMALL_STATE(137)] = 3379,
  [SMALL_STATE(138)] = 3392,
  [SMALL_STATE(139)] = 3405,
  [SMALL_STATE(140)] = 3418,
  [SMALL_STATE(141)] = 3428,
  [SMALL_STATE(142)] = 3436,
  [SMALL_STATE(143)] = 3446,
  [SMALL_STATE(144)] = 3454,
  [SMALL_STATE(145)] = 3464,
  [SMALL_STATE(146)] = 3471,
  [SMALL_STATE(147)] = 3478,
  [SMALL_STATE(148)] = 3485,
  [SMALL_STATE(149)] = 3492,
  [SMALL_STATE(150)] = 3499,
  [SMALL_STATE(151)] = 3506,
  [SMALL_STATE(152)] = 3513,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(144),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [31] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [35] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [37] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(142),
  [40] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(144),
  [43] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(39),
  [46] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(42),
  [49] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(94),
  [52] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(7),
  [55] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(105),
  [58] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(108),
  [61] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(118),
  [64] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(4),
  [67] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(11),
  [70] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(3),
  [73] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [75] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(147),
  [79] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 1, 0, 0),
  [81] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 1, 0, 0),
  [83] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__base_expression, 1, 0, 0),
  [85] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__base_expression, 1, 0, 0),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [93] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [99] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 2, 0, 0),
  [113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 2, 0, 0),
  [115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__base_expression, 3, 0, 0),
  [125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__base_expression, 3, 0, 0),
  [127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 3, 0, 0),
  [129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 3, 0, 0),
  [131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 3, 0, 0),
  [133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 3, 0, 0),
  [135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 3, 0, 0),
  [141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 3, 0, 0),
  [143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 4, 0, 0),
  [145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 4, 0, 0),
  [147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 4, 0, 0),
  [149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 4, 0, 0),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 0),
  [155] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 0),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 5, 0, 0),
  [161] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 5, 0, 0),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 6, 0, 0),
  [167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 6, 0, 0),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 2, 0, 0),
  [177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 2, 0, 0),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multiplicative_expression, 3, 0, 5),
  [197] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_multiplicative_expression, 3, 0, 5),
  [199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_additive_expression, 3, 0, 5),
  [203] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_additive_expression, 3, 0, 5),
  [205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chained_method, 2, 0, 0),
  [207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_chained_method, 2, 0, 0),
  [209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_chained_method_repeat1, 2, 0, 0),
  [211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_chained_method_repeat1, 2, 0, 0),
  [213] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chained_method_repeat1, 2, 0, 0), SHIFT_REPEAT(147),
  [216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 1, 0, 1),
  [218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declarator, 1, 0, 1),
  [220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_call, 5, 0, 0),
  [224] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_call, 5, 0, 0),
  [226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0),
  [232] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0),
  [234] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(140),
  [237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 3, 0, 0),
  [239] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 3, 0, 0),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lexical_declaration, 3, 0, 2),
  [247] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lexical_declaration, 3, 0, 2),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lexical_declaration, 2, 0, 2),
  [253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lexical_declaration, 2, 0, 2),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_call, 4, 0, 0),
  [259] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_call, 4, 0, 0),
  [261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 2, 0, 0),
  [263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 2, 0, 0),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_call, 6, 0, 0),
  [269] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_call, 6, 0, 0),
  [271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_call, 7, 0, 0),
  [273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_call, 7, 0, 0),
  [275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__initializer, 2, 0, 6),
  [281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__initializer, 2, 0, 6),
  [283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 2, 0, 3),
  [285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declarator, 2, 0, 3),
  [287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 3, 0, 4),
  [289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 3, 0, 4),
  [291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment, 2, 0, 0),
  [293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment, 2, 0, 0),
  [295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment, 3, 0, 0),
  [297] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment, 3, 0, 0),
  [299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 4, 0, 0),
  [301] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 4, 0, 0),
  [303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lexical_declaration, 4, 0, 2),
  [305] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lexical_declaration, 4, 0, 2),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_chained_method_repeat1, 2, 0, 0), SHIFT_REPEAT(152),
  [328] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat3, 2, 0, 0), SHIFT_REPEAT(104),
  [331] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat3, 2, 0, 0),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(119),
  [339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [341] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(106),
  [344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(120),
  [346] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat2, 2, 0, 0), SHIFT_REPEAT(110),
  [349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat2, 2, 0, 0),
  [351] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_call_repeat1, 2, 0, 0), SHIFT_REPEAT(40),
  [354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_call_repeat1, 2, 0, 0),
  [356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(115),
  [360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(116),
  [362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(117),
  [364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(78),
  [366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(110),
  [370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(104),
  [372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(121),
  [374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0), SHIFT_REPEAT(99),
  [403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 3, 0, 7),
  [429] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_strudel(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
    .name = "strudel",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 1,
      .minor_version = 1,
      .patch_version = 1,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
